@@ -14,12 +14,12 @@ def pass_bot(_bot):
 
 class ParseMention:
     REGEX_ROLES = r"&lt;@&amp;([0-9]+)&gt;"
-    REGEX_MEMBERS = r"&lt;@!?([0-9]+)&gt;"
-    REGEX_CHANNELS = r"&lt;#([0-9]+)&gt;"
-    REGEX_EMOJIS = r"&lt;a?(:[^\n:]+:)[0-9]+&gt;"
     REGEX_ROLES_2 = r"<@&([0-9]+)>"
+    REGEX_MEMBERS = r"&lt;@!?([0-9]+)&gt;"
     REGEX_MEMBERS_2 = r"<@!?([0-9]+)>"
+    REGEX_CHANNELS = r"&lt;#([0-9]+)&gt;"
     REGEX_CHANNELS_2 = r"<#([0-9]+)>"
+    REGEX_EMOJIS = r"&lt;a?(:[^\n:]+:)[0-9]+&gt;"
     REGEX_EMOJIS_2 = r"<a?(:[^\n:]+:)[0-9]+>"
 
     ESCAPE_LT = "______lt______"
@@ -66,21 +66,27 @@ class ParseMention:
 
     def normal_channel_mention(self):
         offset = 0
-        for match in re.finditer(self.REGEX_CHANNELS, self.content):
+        match = re.search(self.REGEX_CHANNELS, self.content)
+
+        while match is not None:
             channel_id = int(match.group(1))
             channel = self.guild.get_channel(channel_id)
+
             if channel is None:
                 replacement = '#deleted-channel'
             else:
                 replacement = '<span class="mention" title="%s">#%s</span>' \
                               % (channel.name, channel.name)
-            self.content = self.content.replace(self.content[match.start() + offset:match.end() + offset],
-                                                replacement)
+            self.content = self.content.replace(self.content[match.start() + offset:match.end() + offset], replacement)
+
             offset += len(replacement) - (match.end() - match.start())
+            match = re.search(self.REGEX_CHANNELS, self.content)
 
     def html_channel_mention(self):
         offset = 0
-        for match in re.finditer(self.REGEX_CHANNELS_2, self.content):
+        match = re.search(self.REGEX_CHANNELS_2, self.content)
+
+        while match is not None:
             channel_id = int(match.group(1))
             channel = self.guild.get_channel(channel_id)
             if channel is None:
@@ -90,37 +96,48 @@ class ParseMention:
                               % (channel.name, channel.name)
             self.content = self.content.replace(self.content[match.start() + offset:match.end() + offset],
                                                 replacement)
+
             offset += len(replacement) - (match.end() - match.start())
+            match = re.search(self.REGEX_CHANNELS_2, self.content)
 
     def normal_role_mention(self):
         offset = 0
-        for match in re.finditer(self.REGEX_ROLES, self.content):
+        match = re.search(self.REGEX_ROLES, self.content)
+        while match is not None:
             role_id = int(match.group(1))
             role = self.guild.get_role(role_id)
+
             if role is None:
                 replacement = '@deleted-role'
             else:
                 replacement = '<span style="color: #%02x%02x%02x;">@%s</span>' \
                               % (role.color.r, role.color.g, role.color.b, role.name)
             self.content = self.content.replace(self.content[match.start() + offset:match.end() + offset], replacement)
+
             offset += len(replacement) - (match.end() - match.start())
+            match = re.search(self.REGEX_ROLES, self.content)
 
     def html_role_mention(self):
         offset = 0
-        for match in re.finditer(self.REGEX_ROLES_2, self.content):
+        match = re.search(self.REGEX_ROLES_2, self.content)
+        while match is not None:
             role_id = int(match.group(1))
             role = self.guild.get_role(role_id)
+
             if role is None:
                 replacement = '@deleted-role'
             else:
                 replacement = '<span style="color: #%02x%02x%02x;">@%s</span>' \
                               % (role.color.r, role.color.g, role.color.b, role.name)
             self.content = self.content.replace(self.content[match.start() + offset:match.end() + offset], replacement)
+
             offset += len(replacement) - (match.end() - match.start())
+            match = re.search(self.REGEX_ROLES_2, self.content)
 
     def normal_user_mention(self):
         offset = 0
-        for match in re.finditer(self.REGEX_MEMBERS, self.content):
+        match = re.search(self.REGEX_MEMBERS, self.content)
+        while match is not None:
             member_id = int(match.group(1))
 
             member = None
@@ -133,17 +150,18 @@ class ParseMention:
             if member is not None:
                 replacement = '<span class="mention" title="%s">@%s</span>' \
                               % (str(member_id), str(member_name))
-                self.content = self.content.replace(self.content[match.start() + offset:match.end() + offset],
-                                                    replacement)
-                offset += len(replacement) - (match.end() - match.start())
             else:
-                self.content = self.content.replace(self.content[match.start() + offset:match.end() + offset],
-                                                    '<span class="mention" title="%s">@%s</span>' % (
-                                                        "Unknown", "Unknown"))
+                replacement = '<span class="mention" title="Unknown">@Unknown</span>'
+            self.content = self.content.replace(self.content[match.start() + offset:match.end() + offset],
+                                                replacement)
+
+            offset += len(replacement) - (match.end() - match.start())
+            match = re.search(self.REGEX_MEMBERS, self.content)
 
     def html_user_mention(self):
         offset = 0
-        for match in re.finditer(self.REGEX_MEMBERS_2, self.content):
+        match = re.search(self.REGEX_MEMBERS_2, self.content)
+        while match is not None:
             member_id = int(match.group(1))
 
             member = None
@@ -156,10 +174,10 @@ class ParseMention:
             if member is not None:
                 replacement = '<span class="mention" title="%s">@%s</span>' \
                               % (str(member_id), str(member_name))
-                self.content = self.content.replace(self.content[match.start() + offset:match.end() + offset],
-                                                    replacement)
-                offset += len(replacement) - (match.end() - match.start())
             else:
-                self.content = self.content.replace(self.content[match.start() + offset:match.end() + offset],
-                                                    '<span class="mention" title="%s">@%s</span>' % (
-                                                        "Unknown", "Unknown"))
+                replacement = '<span class="mention" title="Unknown">@Unknown</span>'
+            self.content = self.content.replace(self.content[match.start() + offset:match.end() + offset],
+                                                replacement)
+
+            offset += len(replacement) - (match.end() - match.start())
+            match = re.search(self.REGEX_MEMBERS_2, self.content)
